package com.bweb.controller.item;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.config.MathConfig;
import com.hfkj.entity.EnOilDepots;
import com.hfkj.entity.EnOilManagement;
import com.hfkj.entity.EnTransportCompanyCar;
import com.hfkj.model.ResponseData;
import com.hfkj.model.SecUserSessionObject;
import com.hfkj.service.item.EnOilManagementService;
import com.hfkj.service.item.EnTransportCompanyCarService;
import com.hfkj.sysenum.SecUserObjectTypeEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.models.auth.In;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Controller
@RequestMapping(value="/enOilManagement")
@Api(value="油库进销存管理管理")
public class EnOilManagementController {

    Logger log = LoggerFactory.getLogger(EnOilDepotsController.class);
    @Resource
    private UserCenter userCenter;
    @Resource
    private EnOilManagementService enOilManagementService;
    @Resource
    private EnTransportCompanyCarService enTransportCompanyCarService;

    @RequestMapping(value="/oilInOutRecord",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "进出库记录")
    public ResponseData oilInOutRecord(@RequestBody EnOilManagement body) {
        try {
            if (body == null
                    || body.getType() == null
                    || body.getOilType() == null
                    || StringUtils.isBlank(body.getRemark())
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);

            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }
            if (!sessionModel.getAccount().getObjectType().equals(SecUserObjectTypeEnum.type3.getCode())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ROLE_NOT_PERMISSIONS, "");
            }

            // 当类型为出库
            if (body.getType() == 1) {
                if (body.getOutQuantity() == null
                        || body.getOutQuantity().compareTo(BigDecimal.ZERO) <= 0
                        || body.getTransportCarId() == null
                ){
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
                }

                EnTransportCompanyCar enTransportCompanyCar = enTransportCompanyCarService.queryDetail(body.getTransportCarId());
                body.setTransportCarNo(enTransportCompanyCar.getCarNo());
            }

            // 当类型为入库
            if (body.getType() == 2) {
                if (body.getInQuantity() == null
                        || body.getInQuantity().compareTo(BigDecimal.ZERO) <= 0
                        || body.getTransportCarNo() == null
                        || StringUtils.isBlank(body.getSupplier())
                ){
                    throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
                }
            }

            body.setUpdateTime(new Date());
            body.setCreateTime(new Date());
            body.setCreateUser(sessionModel.getAccount().getId());
            body.setStatus(1);
            body.setCreateUserName(sessionModel.getAccount().getUserName());

            enOilManagementService.create(body);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/queryList",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询项目列表")
    public ResponseData queryList(@RequestParam(value = "type" , required = false) Integer type,
                                  @RequestParam(value = "transportCarId" , required = false) Long transportCarId,
                                  @RequestParam(value = "oilType" , required = false) Integer oilType,
                                  @RequestParam(value = "transportCarNo" , required = false) String transportCarNo,
                                  @RequestParam(value = "status" , required = false) Integer status,
                                  @RequestParam(value = "supplier" , required = false) String supplier,
                                  @RequestParam(value = "pageNum" , required = true) Integer pageNum,
                                  @RequestParam(value = "pageSize" , required = true) Integer pageSize) {
        try {
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String,Object> param = new HashMap<>();
            param.put("type", type);
            param.put("transportCarId", transportCarId);
            param.put("oilType", oilType);
            param.put("transportCarNo", transportCarNo);
            param.put("supplier", supplier);
            param.put("status", status);

            PageHelper.startPage(pageNum, pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(enTransportCompanyCarService.getList(param)));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
